You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by se...@apache.org on 2010/12/14 11:18:31 UTC

svn commit: r1049022 - in /directory/apacheds/trunk: jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/ jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/ service-builder/src/m...

Author: seelmann
Date: Tue Dec 14 10:18:30 2010
New Revision: 1049022

URL: http://svn.apache.org/viewvc?rev=1049022&view=rev
Log:
Consistent usage of 'URI partitionPath' for Stores

Modified:
    directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndex.java
    directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmPartition.java
    directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStore.java
    directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndexTest.java
    directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmRdnIndexTest.java
    directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStoreTest.java
    directory/apacheds/trunk/service-builder/src/main/java/org/apache/directory/server/config/ServiceBuilder.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/AbstractStore.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/GenericIndex.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Index.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Store.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlIndex.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlStore.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/GenericIndexTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlRdnIndexTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlStoreTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/AndCursorTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/GreaterEqTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/LessEqTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NestedFilterTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NotCursorTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OneLevelScopeTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OrCursorTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/PresenceTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubstringTest.java
    directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubtreeScopeTest.java

Modified: directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndex.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndex.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndex.java (original)
+++ directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndex.java Tue Dec 14 10:18:30 2010
@@ -23,6 +23,7 @@ package org.apache.directory.server.core
 import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
+import java.net.URI;
 
 import jdbm.RecordManager;
 import jdbm.helper.MRU;
@@ -289,11 +290,11 @@ public class JdbmIndex<K, O> extends Abs
      *
      * @param wkDirPath optional working directory path
      */
-    public void setWkDirPath( File wkDirPath )
+    public void setWkDirPath( URI wkDirPath )
     {
         //.out.println( "IDX Defining a WorkingDir : " + wkDirPath );
         protect( "wkDirPath" );
-        this.wkDirPath = wkDirPath;
+        this.wkDirPath = new File( wkDirPath );
     }
 
 
@@ -303,9 +304,9 @@ public class JdbmIndex<K, O> extends Abs
      *
      * @return optional working directory path 
      */
-    public File getWkDirPath()
+    public URI getWkDirPath()
     {
-        return wkDirPath;
+        return wkDirPath != null ? wkDirPath.toURI() : null;
     }
 
 

Modified: directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmPartition.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmPartition.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmPartition.java (original)
+++ directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmPartition.java Tue Dec 14 10:18:30 2010
@@ -20,8 +20,6 @@
 package org.apache.directory.server.core.partition.impl.btree.jdbm;
 
 
-import java.io.File;
-
 import org.apache.directory.server.core.partition.Partition;
 import org.apache.directory.server.core.partition.impl.xdbm.AbstractXdbmPartition;
 import org.apache.directory.server.xdbm.Index;
@@ -53,7 +51,7 @@ public class JdbmPartition extends Abstr
 
     protected void doInit() throws Exception
     {
-        store.setPartitionDir( new File( getPartitionPath() ) );
+        store.setPartitionPath( getPartitionPath() );
 
         EvaluatorBuilder<Long> evaluatorBuilder = new EvaluatorBuilder<Long>( store, schemaManager );
         CursorBuilder<Long> cursorBuilder = new CursorBuilder<Long>( store, evaluatorBuilder );
@@ -77,7 +75,7 @@ public class JdbmPartition extends Abstr
         // Normalize the suffix
         suffix.normalize( schemaManager );
         store.setSuffixDn( suffix );
-        store.setPartitionDir( new File( getPartitionPath() ) );
+        store.setPartitionPath( getPartitionPath() );
 
         for ( Index<?, Entry, Long> index : getIndexedAttributes() )
         {

Modified: directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStore.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStore.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStore.java (original)
+++ directory/apacheds/trunk/jdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStore.java Tue Dec 14 10:18:30 2010
@@ -109,10 +109,10 @@ public class JdbmStore<E> extends Abstra
     {
         super.init( schemaManager );
 
-        partitionDir.mkdirs();
+        getPartitionDir().mkdirs();
 
         // First, check if the file storing the data exists
-        String path = partitionDir.getPath() + File.separator + "master";
+        String path = getPartitionDir().getPath() + File.separator + "master";
         BaseRecordManager base = new BaseRecordManager( path );
         base.disableTransactions();
 
@@ -305,7 +305,7 @@ public class JdbmStore<E> extends Abstra
             
             if ( jdbmIndex.getWkDirPath() == null )
             {
-                jdbmIndex.setWkDirPath( partitionDir );
+                jdbmIndex.setWkDirPath( partitionPath );
             }
         }
         else
@@ -371,8 +371,14 @@ public class JdbmStore<E> extends Abstra
             }
         }
     }
-    
-    
+
+
+    private File getPartitionDir()
+    {
+        return new File( getPartitionPath() );
+    }
+
+
     /**
      * builds a user defined index on a attribute by browsing all the entries present in master db
      * 

Modified: directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndexTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndexTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndexTest.java (original)
+++ directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmIndexTest.java Tue Dec 14 10:18:30 2010
@@ -119,11 +119,11 @@ public class JdbmIndexTest
             idx.close();
 
             // created by this test
-            File dbFile = new File( idx.getWkDirPath(), idx.getAttribute().getOid() + ".db" );
+            File dbFile = new File( idx.getWkDirPath().getPath(), idx.getAttribute().getOid() + ".db" );
             assertTrue( dbFile.delete() );
 
             // created by TransactionManager, if transactions are not disabled
-            File logFile = new File( idx.getWkDirPath(), idx.getAttribute().getOid() + ".lg" );
+            File logFile = new File( idx.getWkDirPath().getPath(), idx.getAttribute().getOid() + ".lg" );
             
             if ( logFile.exists() )
             {
@@ -138,7 +138,7 @@ public class JdbmIndexTest
     void initIndex() throws Exception
     {
         JdbmIndex<String, Entry> index = new JdbmIndex<String, Entry>();
-        index.setWkDirPath( dbFileDir );
+        index.setWkDirPath( dbFileDir.toURI() );
         initIndex( index );
     }
 
@@ -188,7 +188,7 @@ public class JdbmIndexTest
 
         destroyIndex();
         JdbmIndex<String, Entry> index = new JdbmIndex<String, Entry>( "foo" );
-        index.setWkDirPath( dbFileDir );
+        index.setWkDirPath( dbFileDir.toURI() );
         initIndex( index );
         assertEquals( "foo", idx.getAttributeId() );
     }
@@ -223,29 +223,29 @@ public class JdbmIndexTest
 
         // uninitialized index
         JdbmIndex<String, Entry> jdbmIndex = new JdbmIndex<String, Entry>();
-        jdbmIndex.setWkDirPath( wkdir );
-        assertEquals( "foo", jdbmIndex.getWkDirPath().getName() );
+        jdbmIndex.setWkDirPath( wkdir.toURI() );
+        assertEquals( "foo", new File( jdbmIndex.getWkDirPath() ).getName() );
 
         // initialized index
         initIndex();
         
         try
         {
-            idx.setWkDirPath( wkdir );
+            idx.setWkDirPath( wkdir.toURI() );
             fail( "Should not be able to set wkDirPath after initialization." );
         }
         catch ( Exception e )
         {
         }
         
-        assertEquals( dbFileDir, idx.getWkDirPath() );
+        assertEquals( dbFileDir.toURI(), idx.getWkDirPath() );
 
         destroyIndex();
         jdbmIndex = new JdbmIndex<String, Entry>();
         wkdir.mkdirs();
-        jdbmIndex.setWkDirPath( wkdir );
+        jdbmIndex.setWkDirPath( wkdir.toURI() );
         initIndex( jdbmIndex );
-        assertEquals( wkdir, idx.getWkDirPath() );
+        assertEquals( wkdir.toURI(), idx.getWkDirPath() );
     }
 
 
@@ -576,7 +576,7 @@ public class JdbmIndexTest
         try
         {
             AttributeType noEqMatchAttribute = new AttributeType( "1.1" );
-            jdbmIndex.setWkDirPath( dbFileDir );
+            jdbmIndex.setWkDirPath( dbFileDir.toURI() );
             jdbmIndex.init( schemaManager, noEqMatchAttribute );
             fail( "should not get here" );
         }
@@ -594,7 +594,7 @@ public class JdbmIndexTest
     public void testSingleValuedAttribute() throws Exception
     {
         JdbmIndex<Object, Object> jdbmIndex = new JdbmIndex<Object, Object>();
-        jdbmIndex.setWkDirPath( dbFileDir );
+        jdbmIndex.setWkDirPath( dbFileDir.toURI() );
         jdbmIndex.init( schemaManager, schemaManager.lookupAttributeTypeRegistry( SchemaConstants.CREATORS_NAME_AT ) );
         jdbmIndex.close();
     }

Modified: directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmRdnIndexTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmRdnIndexTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmRdnIndexTest.java (original)
+++ directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmRdnIndexTest.java Tue Dec 14 10:18:30 2010
@@ -119,11 +119,11 @@ public class JdbmRdnIndexTest
             idx.close();
 
             // created by this test
-            File dbFile = new File( idx.getWkDirPath(), idx.getAttribute().getOid() + ".db" );
+            File dbFile = new File( idx.getWkDirPath().getPath(), idx.getAttribute().getOid() + ".db" );
             assertTrue( dbFile.delete() );
 
             // created by TransactionManager, if transactions are not disabled
-            File logFile = new File( idx.getWkDirPath(), idx.getAttribute().getOid() + ".lg" );
+            File logFile = new File( idx.getWkDirPath().getPath(), idx.getAttribute().getOid() + ".lg" );
             
             if ( logFile.exists() )
             {
@@ -138,7 +138,7 @@ public class JdbmRdnIndexTest
     void initIndex() throws Exception
     {
         JdbmRdnIndex<Long> index = new JdbmRdnIndex<Long>();
-        index.setWkDirPath( dbFileDir );
+        index.setWkDirPath( dbFileDir.toURI() );
         initIndex( index );
     }
 
@@ -192,30 +192,30 @@ public class JdbmRdnIndexTest
 
         // uninitialized index
         JdbmRdnIndex<Long> jdbmRdnIndex = new JdbmRdnIndex<Long>();
-        jdbmRdnIndex.setWkDirPath( wkdir );
-        assertEquals( "foo", jdbmRdnIndex.getWkDirPath().getName() );
+        jdbmRdnIndex.setWkDirPath( wkdir.toURI() );
+        assertEquals( "foo", new File( jdbmRdnIndex.getWkDirPath() ).getName() );
 
         // initialized index
         initIndex();
         
         try
         {
-            idx.setWkDirPath( wkdir );
+            idx.setWkDirPath( wkdir.toURI() );
             fail( "Should not be able to set wkDirPath after initialization." );
         }
         catch ( Exception e )
         {
         }
         
-        assertEquals( dbFileDir, idx.getWkDirPath() );
+        assertEquals( dbFileDir.toURI(), idx.getWkDirPath() );
 
         destroyIndex();
         
         jdbmRdnIndex = new JdbmRdnIndex<Long>();
         wkdir.mkdirs();
-        jdbmRdnIndex.setWkDirPath( wkdir );
+        jdbmRdnIndex.setWkDirPath( wkdir.toURI() );
         initIndex( jdbmRdnIndex );
-        assertEquals( wkdir, idx.getWkDirPath() );
+        assertEquals( wkdir.toURI(), idx.getWkDirPath() );
     }
 
 

Modified: directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStoreTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStoreTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStoreTest.java (original)
+++ directory/apacheds/trunk/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/impl/btree/jdbm/JdbmStoreTest.java Tue Dec 14 10:18:30 2010
@@ -150,15 +150,15 @@ public class JdbmStoreTest
         store = new JdbmStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         JdbmIndex ouIndex = new JdbmIndex( SchemaConstants.OU_AT_OID );
-        ouIndex.setWkDirPath( wkdir );
+        ouIndex.setWkDirPath( wkdir.toURI() );
         store.addIndex( ouIndex );
         
         JdbmIndex uidIndex = new JdbmIndex( SchemaConstants.UID_AT_OID );
-        uidIndex.setWkDirPath( wkdir );
+        uidIndex.setWkDirPath( wkdir.toURI() );
         store.addIndex( uidIndex );
 
         StoreUtils.loadExampleData( store, schemaManager );
@@ -204,7 +204,7 @@ public class JdbmStoreTest
         JdbmStore<Entry> store2 = new JdbmStore<Entry>();
         store2.setId( "example2" );
         store2.setCacheSize( 10 );
-        store2.setPartitionDir( wkdir2 );
+        store2.setPartitionPath( wkdir2.toURI() );
         store2.setSyncOnWrite( false );
         store2.addIndex( new JdbmIndex( SchemaConstants.OU_AT_OID ) );
         store2.addIndex( new JdbmIndex( SchemaConstants.UID_AT_OID ) );
@@ -283,9 +283,9 @@ public class JdbmStoreTest
         store.addIndex( new JdbmIndex<Object, Attributes>( "1.2.3.4" ) );
         assertEquals( 1, store.getUserIndices().size() );
 
-        assertNull( store.getPartitionDir() );
-        store.setPartitionDir( new File( "." ) );
-        assertEquals( new File( "." ), store.getPartitionDir() );
+        assertNull( store.getPartitionPath() );
+        store.setPartitionPath( new File( "." ).toURI() );
+        assertEquals( new File( "." ).toURI(), store.getPartitionPath() );
 
         assertFalse( store.isInitialized() );
         assertTrue( store.isSyncOnWrite() );
@@ -460,10 +460,10 @@ public class JdbmStoreTest
         {
         }
 
-        assertNotNull( store.getPartitionDir() );
+        assertNotNull( store.getPartitionPath() );
         try
         {
-            store.setPartitionDir( new File( "." ) );
+            store.setPartitionPath( new File( "." ).toURI() );
             fail();
         }
         catch ( IllegalStateException e )
@@ -654,7 +654,7 @@ public class JdbmStoreTest
         File testSpecificDir = new File( wkdir, "testConvertIndex" );
         testSpecificDir.mkdirs();
 
-        Index<?, Object, Long> nonJdbmIndex = new GenericIndex<Object, Object, Long>( "ou", 10, testSpecificDir );
+        Index<?, Object, Long> nonJdbmIndex = new GenericIndex<Object, Object, Long>( "ou", 10, testSpecificDir.toURI() );
 
         Method convertIndex = store.getClass().getDeclaredMethod( "convertAndInit", Index.class );
         convertIndex.setAccessible( true );
@@ -933,7 +933,7 @@ public class JdbmStoreTest
         store = new JdbmStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
         // do not add ou index this time
         store.addIndex( new JdbmIndex( SchemaConstants.UID_AT_OID ) );

Modified: directory/apacheds/trunk/service-builder/src/main/java/org/apache/directory/server/config/ServiceBuilder.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/service-builder/src/main/java/org/apache/directory/server/config/ServiceBuilder.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/service-builder/src/main/java/org/apache/directory/server/config/ServiceBuilder.java (original)
+++ directory/apacheds/trunk/service-builder/src/main/java/org/apache/directory/server/config/ServiceBuilder.java Tue Dec 14 10:18:30 2010
@@ -994,12 +994,12 @@ public class ServiceBuilder
         
         if ( jdbmIndexBean.getIndexWorkingDir() != null )
         {
-            index.setWkDirPath( new File( jdbmIndexBean.getIndexWorkingDir() ) );
+            index.setWkDirPath( new File( jdbmIndexBean.getIndexWorkingDir() ).toURI() );
         }
         else
         {
             // Set the Partition working dir as a default
-            index.setWkDirPath( new File( partition.getPartitionPath() ) );
+            index.setWkDirPath( partition.getPartitionPath() );
         }
                 
         return index;

Modified: directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/AbstractStore.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/AbstractStore.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/AbstractStore.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/AbstractStore.java Tue Dec 14 10:18:30 2010
@@ -20,7 +20,7 @@
 package org.apache.directory.server.xdbm;
 
 
-import java.io.File;
+import java.net.URI;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -80,8 +80,8 @@ public abstract class AbstractStore<E, I
     /** true if initialized */
     protected boolean initialized;
 
-    /** the partition directory to use for files */
-    protected File partitionDir;
+    /** the partition path to use for files */
+    protected URI partitionPath;
 
     /** true if we sync disks on every write operation */
     protected boolean isSyncOnWrite = true;
@@ -172,16 +172,16 @@ public abstract class AbstractStore<E, I
     }
 
 
-    public void setPartitionDir( File partitionDir )
+    public void setPartitionPath( URI partitionPath )
     {
-        protect( "partitionDir" );
-        this.partitionDir = partitionDir;
+        protect( "partitionPath" );
+        this.partitionPath = partitionPath;
     }
 
 
-    public File getPartitionDir()
+    public URI getPartitionPath()
     {
-        return partitionDir;
+        return partitionPath;
     }
 
 
@@ -304,70 +304,70 @@ public abstract class AbstractStore<E, I
         if ( getPresenceIndex() == null )
         {
             Index<String, E, ID> index = new GenericIndex<String, E, ID>( ApacheSchemaConstants.APACHE_EXISTENCE_AT_OID ) ;
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getOneLevelIndex() == null )
         {
             Index<ID, E, ID> index = new GenericIndex<ID, E, ID>( ApacheSchemaConstants.APACHE_ONE_LEVEL_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getSubLevelIndex() == null )
         {
             Index<ID, E, ID> index = new GenericIndex<ID, E, ID>( ApacheSchemaConstants.APACHE_SUB_LEVEL_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getRdnIndex() == null )
         {
             Index<ParentIdAndRdn<ID>, E, ID> index = new GenericIndex<ParentIdAndRdn<ID>, E, ID>( ApacheSchemaConstants.APACHE_RDN_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getAliasIndex() == null )
         {
             Index<String, E, ID> index = new GenericIndex<String, E, ID>( ApacheSchemaConstants.APACHE_ALIAS_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getOneAliasIndex() == null )
         {
             Index<ID, E, ID> index = new GenericIndex<ID, E, ID>( ApacheSchemaConstants.APACHE_ONE_ALIAS_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getSubAliasIndex() == null )
         {
             Index<ID, E, ID> index = new GenericIndex<ID, E, ID>( ApacheSchemaConstants.APACHE_SUB_ALIAS_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getObjectClassIndex() == null )
         {
             Index<String, E, ID> index = new GenericIndex<String, E, ID>( SchemaConstants.OBJECT_CLASS_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getEntryUuidIndex() == null )
         {
             Index<String, E, ID> index = new GenericIndex<String, E, ID>( SchemaConstants.ENTRY_UUID_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 
         if ( getEntryCsnIndex() == null )
         {
             Index<String, E, ID> index = new GenericIndex<String, E, ID>( SchemaConstants.ENTRY_CSN_AT_OID );
-            index.setWkDirPath( partitionDir );
+            index.setWkDirPath( partitionPath );
             addIndex( index );
         }
 

Modified: directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/GenericIndex.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/GenericIndex.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/GenericIndex.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/GenericIndex.java Tue Dec 14 10:18:30 2010
@@ -20,7 +20,7 @@
 package org.apache.directory.server.xdbm;
 
 
-import java.io.File;
+import java.net.URI;
 
 import org.apache.directory.shared.ldap.cursor.Cursor;
 import org.apache.directory.shared.ldap.schema.AttributeType;
@@ -35,7 +35,7 @@ import org.apache.directory.shared.ldap.
 public class GenericIndex<K, O, ID> extends AbstractIndex<K, O, ID>
 {
     /** Index working directory */
-    protected File wkDirPath;
+    protected URI wkDirPath;
 
 
     /**
@@ -68,7 +68,7 @@ public class GenericIndex<K, O, ID> exte
      * @param cacheSize the cache size
      * @param wkDirPath the working directory
      */
-    public GenericIndex( String attributeId, int cacheSize, File wkDirPath )
+    public GenericIndex( String attributeId, int cacheSize, URI wkDirPath )
     {
         super( attributeId );
         this.cacheSize = cacheSize;
@@ -220,7 +220,7 @@ public class GenericIndex<K, O, ID> exte
     }
 
 
-    public File getWkDirPath()
+    public URI getWkDirPath()
     {
         return wkDirPath;
     }
@@ -268,7 +268,7 @@ public class GenericIndex<K, O, ID> exte
     }
 
 
-    public void setWkDirPath( File wkDirPath )
+    public void setWkDirPath( URI wkDirPath )
     {
         this.wkDirPath = wkDirPath;
     }

Modified: directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Index.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Index.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Index.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Index.java Tue Dec 14 10:18:30 2010
@@ -20,7 +20,7 @@
 package org.apache.directory.server.xdbm;
 
 
-import java.io.File;
+import java.net.URI;
 
 import org.apache.directory.shared.ldap.cursor.Cursor;
 import org.apache.directory.shared.ldap.schema.AttributeType;
@@ -88,7 +88,7 @@ public interface Index<K, O, ID>
      *
      * @param wkDirPath optional working directory path
      */
-    void setWkDirPath( File wkDirPath );
+    void setWkDirPath( URI wkDirPath );
 
 
     /**
@@ -97,7 +97,7 @@ public interface Index<K, O, ID>
      *
      * @return optional working directory path
      */
-    File getWkDirPath();
+    URI getWkDirPath();
 
 
     /**

Modified: directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Store.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Store.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlIndex.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlIndex.java Tue Dec 14 10:18:30 2010
@@ -20,7 +20,7 @@
 package org.apache.directory.server.xdbm.impl.avl;
 
 
-import java.io.File;
+import java.net.URI;
 
 import org.apache.directory.server.core.partition.impl.btree.IndexCursorAdaptor;
 import org.apache.directory.server.core.partition.impl.btree.LongComparator;
@@ -415,7 +415,7 @@ public class AvlIndex<K, O> extends Abst
     /**
      * throws UnsupportedOperationException cause it is a in-memory index
      */
-    public void setWkDirPath( File wkDirPath )
+    public void setWkDirPath( URI wkDirPath )
     {
         throw new UnsupportedOperationException( I18n.err( I18n.ERR_213 ) );
     }
@@ -424,7 +424,7 @@ public class AvlIndex<K, O> extends Abst
     /**
      * this method always returns null for AvlIndex cause this is a in-memory index.
      */
-    public File getWkDirPath()
+    public URI getWkDirPath()
     {
         return null;
     }

Modified: directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlStore.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlStore.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlStore.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlStore.java Tue Dec 14 10:18:30 2010
@@ -20,7 +20,7 @@
 package org.apache.directory.server.xdbm.impl.avl;
 
 
-import java.io.File;
+import java.net.URI;
 
 import org.apache.directory.server.constants.ApacheSchemaConstants;
 import org.apache.directory.server.core.partition.impl.btree.LongComparator;
@@ -133,7 +133,7 @@ public class AvlStore<E> extends Abstrac
      * always returns null, cause this is a in-memory store
      */
     @Override
-    public File getPartitionDir()
+    public URI getPartitionPath()
     {
         // returns null always
         return null;

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/GenericIndexTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/GenericIndexTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/GenericIndexTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/GenericIndexTest.java Tue Dec 14 10:18:30 2010
@@ -46,7 +46,7 @@ public class GenericIndexTest
     public void setUp()
     {
         String tmpDir = System.getProperty( "java.io.tmpdir" );
-        index = new GenericIndex<String, Long, Long>( "cn", 42, new File( tmpDir ) );
+        index = new GenericIndex<String, Long, Long>( "cn", 42, new File( tmpDir ).toURI() );
     }
 
 
@@ -75,11 +75,11 @@ public class GenericIndexTest
     {
         File tmpDir = new File(System.getProperty( "java.io.tmpdir" ));
 
-        index = new GenericIndex<String, Long, Long>( "cn", 42, tmpDir );
+        index = new GenericIndex<String, Long, Long>( "cn", 42, tmpDir.toURI() );
         assertEquals( "cn", index.getAttributeId() );
         assertEquals( 42, index.getCacheSize() );
         assertNotNull( index.getWkDirPath() );
-        assertEquals( tmpDir.getPath(), index.getWkDirPath().getPath() );
+        assertEquals( tmpDir.toURI().getPath(), index.getWkDirPath().getPath() );
     }
 
 
@@ -111,7 +111,7 @@ public class GenericIndexTest
         File tmpDir = new File( System.getProperty( "java.io.tmpdir" ));
         File zzzDir = new File( tmpDir, "zzz"  );
 
-        index.setWkDirPath( zzzDir );
+        index.setWkDirPath( zzzDir.toURI() );
         assertNotNull( index.getWkDirPath() );
         assertEquals( zzzDir.getPath(), index.getWkDirPath().getPath() );
         index.setWkDirPath( null );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlRdnIndexTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlRdnIndexTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlRdnIndexTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlRdnIndexTest.java Tue Dec 14 10:18:30 2010
@@ -161,7 +161,7 @@ public class AvlRdnIndexTest
     {
         // uninitialized index
         AvlRdnIndex AvlRdnIndex = new AvlRdnIndex();
-        AvlRdnIndex.setWkDirPath( new File( dbFileDir, "foo" ) );
+        AvlRdnIndex.setWkDirPath( new File( dbFileDir, "foo" ).toURI() );
     }
 
 

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlStoreTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlStoreTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlStoreTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/impl/avl/AvlStoreTest.java Tue Dec 14 10:18:30 2010
@@ -204,9 +204,9 @@ public class AvlStoreTest
         store.addIndex( new AvlIndex<Object, Attributes>( "1.2.3.4" ) );
         assertEquals( 1, store.getUserIndices().size() );
 
-        assertNull( store.getPartitionDir() );
-        store.setPartitionDir( new File( "." ) );
-        assertNull( store.getPartitionDir() );
+        assertNull( store.getPartitionPath() );
+        store.setPartitionPath( new File( "." ).toURI() );
+        assertNull( store.getPartitionPath() );
 
         assertFalse( store.isInitialized() );
         assertFalse( store.isSyncOnWrite() );
@@ -382,7 +382,7 @@ public class AvlStoreTest
         {
         }
 
-        assertNull( store.getPartitionDir() );
+        assertNull( store.getPartitionPath() );
         assertTrue( store.isInitialized() );
         assertFalse( store.isSyncOnWrite() );
 
@@ -558,7 +558,7 @@ public class AvlStoreTest
     @Test
     public void testConvertIndex() throws Exception
     {
-        Index nonAvlIndex = new GenericIndex( "ou", 10, new File( "." ) );
+        Index nonAvlIndex = new GenericIndex( "ou", 10, new File( "." ).toURI() );
 
         Method convertIndex = store.getClass().getDeclaredMethod( "convertAndInit", Index.class );
         convertIndex.setAccessible( true );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/AndCursorTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/AndCursorTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/AndCursorTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/AndCursorTest.java Tue Dec 14 10:18:30 2010
@@ -131,7 +131,7 @@ public class AndCursorTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/GreaterEqTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/GreaterEqTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/GreaterEqTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/GreaterEqTest.java Tue Dec 14 10:18:30 2010
@@ -131,7 +131,7 @@ public class GreaterEqTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/LessEqTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/LessEqTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/LessEqTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/LessEqTest.java Tue Dec 14 10:18:30 2010
@@ -131,7 +131,7 @@ public class LessEqTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NestedFilterTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NestedFilterTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NestedFilterTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NestedFilterTest.java Tue Dec 14 10:18:30 2010
@@ -129,7 +129,7 @@ public class NestedFilterTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NotCursorTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NotCursorTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NotCursorTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/NotCursorTest.java Tue Dec 14 10:18:30 2010
@@ -128,7 +128,7 @@ public class NotCursorTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OneLevelScopeTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OneLevelScopeTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OneLevelScopeTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OneLevelScopeTest.java Tue Dec 14 10:18:30 2010
@@ -123,7 +123,7 @@ public class OneLevelScopeTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( true );
 
         store.addIndex( new AvlIndex<String, Entry>( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OrCursorTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OrCursorTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OrCursorTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/OrCursorTest.java Tue Dec 14 10:18:30 2010
@@ -130,7 +130,7 @@ public class OrCursorTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/PresenceTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/PresenceTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/PresenceTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/PresenceTest.java Tue Dec 14 10:18:30 2010
@@ -118,7 +118,7 @@ public class PresenceTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubstringTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubstringTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubstringTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubstringTest.java Tue Dec 14 10:18:30 2010
@@ -114,7 +114,7 @@ public class SubstringTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( false );
 
         store.addIndex( new AvlIndex( SchemaConstants.OU_AT_OID ) );

Modified: directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubtreeScopeTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubtreeScopeTest.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================
--- directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubtreeScopeTest.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/test/java/org/apache/directory/server/xdbm/search/impl/SubtreeScopeTest.java Tue Dec 14 10:18:30 2010
@@ -123,7 +123,7 @@ public class SubtreeScopeTest
         store = new AvlStore<Entry>();
         store.setId( "example" );
         store.setCacheSize( 10 );
-        store.setPartitionDir( wkdir );
+        store.setPartitionPath( wkdir.toURI() );
         store.setSyncOnWrite( true );
 
         store.addIndex( new AvlIndex<String, Entry>( SchemaConstants.OU_AT_OID ) );
--- directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Store.java (original)
+++ directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/Store.java Tue Dec 14 10:18:30 2010
@@ -20,7 +20,7 @@
 package org.apache.directory.server.xdbm;
 
 
-import java.io.File;
+import java.net.URI;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
@@ -119,19 +119,19 @@ public interface Store<E, ID extends Com
 
 
     /**
      * Sets the partition directory (working directory) for the store.
      * 
      * @param partitionDir the new partition directory
      */
-    void setPartitionDir( File partitionDir );
+    void setPartitionPath( URI partitionPath );
 
 
     /**
      * Gets the partition directory (working directory) for the store.
      * 
      * @return The current partition directory (working directory) for the store
      */
-    File getPartitionDir();
+    URI getPartitionPath();
 
 
     /**
@@ -119,19 +119,19 @@ public interface Store<E, ID extends Com
 
     /**
-     * Sets the partition directory (working directory) for the store.
+     * Sets the partition path (working directory) for the store.
      * 
@@ -119,19 +119,19 @@ public interface Store<E, ID extends Com
      * 
-     * @param partitionDir the new partition directory
+     * @param partitionDir the new partition path
      */
@@ -119,19 +119,19 @@ public interface Store<E, ID extends Com
 
     /**
-     * Gets the partition directory (working directory) for the store.
+     * Gets the partition path (working directory) for the store.
      * 
@@ -119,19 +119,19 @@ public interface Store<E, ID extends Com
      * 
-     * @return The current partition directory (working directory) for the store
+     * @return The current partition path (working directory) for the store
      */

Modified: directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlIndex.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/xdbm/impl/avl/AvlIndex.java?rev=1049022&r1=1049021&r2=1049022&view=diff
==============================================================================